#include <sys/wait.h>

int INHERENT_fork(){ return 1; }
int WAIT_WNOHANG = WNOHANG;
